@@ -1,4 +1,4 @@
-# Copyright 2004-2015 Tom Rothamel <pytom@bishoujo.us>
+# Copyright 2004-2016 Tom Rothamel <pytom@bishoujo.us>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation files
@@ -74,6 +74,14 @@ pure_functions = {
     "ui.callsinnewcontext",
     "ui.invokesinnewcontext",
     "ui.gamemenus",
+
+    # renpy.py
+
+    "renpy.version_string",
+    "renpy.version_only",
+    "renpy.version_tuple",
+    "renpy.version_name",
+    "renpy.license",
     }
 
 constants = { "config", "style" } | always_constants | pure_functions
@@ -214,6 +222,17 @@ class DeltaSet(object):
     def copy(self):
         return DeltaSet(self.base, self)
 
+    def __iter__(self):
+
+        for i in self.base:
+            if i not in self.removed:
+                yield i
+
+        for i in self.added:
+            yield i
+
+
+
 
 class Analysis(object):
     """
